<?php
/**
 * This file defines functions used for displaying the comments section
 *
 * @package			Wordsmith
 * @copyright		Copyright (C) 2013 Victor Sarabia
 * @license			http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License v2
 * @since			Wordsmith 0.1
 */




/**
 * Template for pings
 *
 * Used as callback for wp_list_comments() to display pingbacks and trackbacks.
 *
 * @uses		comment_author_link()
 *
 * @param		object	$comment	Comment data object.
 * @param		array	$args		Arguments passed by wp_list_comments()
 * @param		int		$depth		Depth of comment in reference to parents.
 */
function wordsmith_display_ping( $comment, $args, $depth ) {
	$GLOBALS[ 'comment' ] = $comment;

	?>
		<li class="ping-item" >
			<?php comment_author_link(); ?>

	<?php
}




/**
 * Template for comments
 *
 * Used as callback for wp_list_comments() to display each comment.
 *
 * @uses		comment_class()
 * @uses		comment_ID()
 * @uses		get_avatar()
 * @uses		comment_author()
 * @uses		get_comment_author()
 * @uses		date_i18n()
 * @uses		get_comment_date()
 * @uses		get_option()
 * @uses		comment_reply_link()
 * @uses		comment_text()

 *
 * @param		object	$comment	Comment data object.
 * @param		array	$args		Arguments passed by wp_list_comments()
 * @param		int		$depth		Depth of comment in reference to parents.
 */
function wordsmith_display_comment( $comment, $args, $depth ) {
	$GLOBALS[ 'comment' ] = $comment;

	$threaded = get_option( 'thread_comments' );
	$parent = $comment->comment_parent;
	$comment_date = date_i18n( get_option( 'date_format' ), strtotime( get_comment_date( 'n/j/Y' ) ) );

	$avatar_size = 48;
	if ( $threaded && '0' != $parent ) {
		$avatar_size = 32;
	}

	$reply_link_args = array(
		'reply_text'	=> __( 'Reply', 'wordsmith' ),
		'depth'			=> $depth,
		'max_depth'		=> $args[ 'max_depth' ]
	);

	/* Threaded Comments Enabled */
	if ( $threaded ) : ?>

		<li <?php comment_class( 'comment-item' ); ?> >
			<article id="comment-<?php comment_ID(); ?>" >
                <footer class="comment-meta">
					<?php echo get_avatar( $comment, $avatar_size ); ?>
                    <span class="comment-author"><?php comment_author(); ?></span>
                    <span class="comment-date">&#8211; <?php echo $comment_date; ?></span>
					<?php comment_reply_link( array_merge( $args, $reply_link_args ) ); ?>
                </footer>
                <div class="comment-text"><?php comment_text(); ?></div>
            </article>

	<?php
	/* Threaded Comments Disabled */
	else: ?>

		<li <?php comment_class( 'comment-item' ); ?> >
			<article id="comment-<?php comment_ID(); ?>" >
				<footer class="comment-meta">
					<?php echo get_avatar( $comment, $avatar_size ); ?>
					<span class="comment-author"><?php comment_author(); ?></span>
					<span class="comment-date">&#8211; <?php echo $comment_date; ?></span>
				</footer>
				<div class="comment-text"><?php comment_text(); ?></div>
			</article>

	<?php endif;
}




/**
 * Prints pagination links for the comments on the current post.
 *
 * @uses		paginate_comments_links()
 */
function wordsmith_comments_pagination() {

	$nav_links = paginate_comments_links(
		array(
			'prev_text'	=> __( '&laquo; Previous', 'wordsmith' ),
			'next_text'	=> __( 'Next &raquo;', 'wordsmith' ),
			'echo'		=> false
		)
	);

	if ( $nav_links ) {
		echo '<p class="comments-pagination">' . $nav_links . '</p>';
	}
}




/**
 * Customize the output of the comment form
 *
 * Filter Hook: comment_form_defaults
 *
 * Removes the website field and the allowed tags section from the comment form
 * Sets the text for the title
 * Adds CSS classes for styling
 *
 * @uses		get_permalink()
 * @uses		wp_get_current_commenter()
 * @uses		get_option()
 * @uses		esc_attr()
 * @uses		wp_login_url()
 * @uses		wp_get_current_user()
 * @uses		admin_url()
 * @uses		wp_logout_url()
 * @uses		wp_parse_args()
 *
 * @param		array	$defaults	Default options for strings, fields etc in the form
 * @return		array	Array with new defaults
 */
function wordsmith_comment_form_defaults( $defaults ) {

	global $wp_query;

	$permalink = get_permalink();
	$commenter = wp_get_current_commenter();

	$title_reply = __( 'Leave a comment', 'wordsmith' );
	// Change the title if it is the first comment
	if ( empty( $wp_query->comments_by_type['comment'] ) ) {
		$title_reply = sprintf( '<span class="notice nocomments">%1$s</span> %2$s',
			__( 'No comments yet', 'wordsmith' ),
			__( 'Be the first to comment', 'wordsmith' )
		);
	}

	$req_text = '';
	if ( get_option( 'require_name_email' ) ) {
		$req_text = sprintf( '<span class="required">(%s)</span>', __( 'required', 'wordsmith' ) );
	}

	$fields = array(
		'author' => sprintf(
			'<p class="respond-item"><label for="comment-form-name" class="respond-label">%1$s: %2$s</label><input id="comment-form-name" name="author" type="text" value="%3$s" size="30" class="respond-input"></p>',
			__( 'Name', 'wordsmith' ),
			$req_text,
			esc_attr( $commenter[ 'comment_author' ] )
		),
		'email' => sprintf(
			'<p class="respond-item"><label for="comment-form-email" class="respond-label">%1$s: %2$s</label><input id="comment-form-email" name="email" type="email" value="%3$s" size="30" class="respond-input"></p>',
			__( 'Email', 'wordsmith' ),
			$req_text,
			esc_attr( $commenter[ 'comment_author_email' ] )
		)
	);

	$textarea = sprintf(
		'<p><label for="comment" class="respond-label hidden-label">%s: </label><textarea id="comment" name="comment" class="respond-input"></textarea></p>',
		__( 'Your comment', 'wordsmith' )
	);

	$must_log_in = sprintf(
		'<p class="must-log-in">%1$s.</p><a href="%2$s">%3$s</a>',
		__( 'You must be logged in to post a comment', 'wordsmith' ),
		wp_login_url( $permalink ),
		__( 'Log in here', 'wordsmith' )
	);

	$user = wp_get_current_user();
	$user_identity = $user->exists() ? $user->display_name : '';

	$logged_in_as =	sprintf(
		'<p class="logged-in-as">%1$s <a href="%2$s" class="logged-user">%3$s</a>. <a href="%4$s" title="%5$s" class="logout-link">%6$s</a></p>',
		__( 'Logged in as', 'wordsmith' ),
		admin_url( 'profile.php' ),
		$user_identity,
		wp_logout_url( $permalink ),
		__( 'Log out of this account', 'wordsmith' ),
		__( 'Log out', 'wordsmith' )
	);

	$new_defaults = array(
		'fields'				=> $fields,
		'comment_field'			=> $textarea,
		'must_log_in'			=> $must_log_in,
		'logged_in_as'			=> $logged_in_as,
		'comment_notes_before'	=> '',
		'comment_notes_after'	=> '',
		'id_form'				=> 'comment-form',
		'id_submit'				=> 'submit-comment',
		'title_reply'			=> $title_reply,
		'title_reply_to'		=> __( 'Leave a reply to: %s', 'wordsmith' ),
		'cancel_reply_link'		=> __( 'Cancel reply', 'wordsmith' ),
		'label_submit'			=> __( 'Submit Comment', 'wordsmith' )
	);

	$output = wp_parse_args( $new_defaults, $defaults );

	return $output;
}
add_filter( 'comment_form_defaults', 'wordsmith_comment_form_defaults' );




/**
 * Prints the "Comments are closed" message
 *
 * Filter Hook: comment_form_comments_closed
 *
 * The message replaces the comment form if comments are closed.
 * If it is a page, the message will only be shown if the page already has comments.
 */
function wordsmith_comments_closed() {

	global $wp_query;

	$has_comments = empty( $wp_query->comments_by_type['comment'] ) ? false : true;

	if ( $has_comments || ! is_page() ) {
		echo '<p class="notice">' . __( 'Comments are closed', 'wordsmith' ) . '<p>';
	}
}
add_filter( 'comment_form_comments_closed', 'wordsmith_comments_closed' );




/**
 * Enqueue comment-reply javascript
 *
 * Action Hook: comment_form_before
 */
function wordsmith_comment_reply_js() {

	if ( get_option('thread_comments') ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'comment_form_before', 'wordsmith_comment_reply_js' );