<?php
/**
 * General Hooked Functions.
 *
 * This file defines callback functions for action/filter hooks.
 *
 * @package			Wordsmith
 * @copyright		Copyright (C) 2013 Victor Sarabia
 * @license			http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License v2
 * @since			Wordsmith 0.1
 */




/*	==========================================================================
	Wordpress Hooks
	========================================================================== */


/**
 * Customize the text contained between the meta <title> tags.
 *
 * Appends the blog title to the right of the default document title.
 *
 * Filter Hook: wp_title
 *
 * @uses		wordsmith_get_default_title()
 * @uses		get_bloginfo()
 * @uses		is_singular()
 *
 * @param		string	$title			Page title returned by wp_title()
 * @param		string	$sep			Used to separate the various items within the page title.
 * @param		string	$seplocation	Direction to display title
 * @return		string	The new Page Meta Title
 */
function wordsmith_meta_title( $title, $sep, $seplocation ) {

	// If the post/page has no title, use the default title
	if ( ! $title && is_singular() ) {
		$title = wordsmith_get_default_title() . " {$sep} ";
	}

	$title .= get_bloginfo( 'name' );
	return $title;
}
add_filter( 'wp_title', 'wordsmith_meta_title', 10, 3 );




/**
 * Enqueue scripts and styles
 *
 * Action Hook: wp_enqueue_scripts
 *
 * @uses		wp_enqueue_script()
 * @uses		get_template_directory_uri()
 */
function wordsmith_scripts() {

	// Enable use of HTML5 sectioning elements in legacy Internet Explorer.
	// https://github.com/aFarkas/html5shiv
	wp_enqueue_script( 'html5-shiv', get_template_directory_uri() . '/js/html5.js' );
}
add_action( 'wp_enqueue_scripts', 'wordsmith_scripts' );




/**
 * Use the default title if the post has no title
 *
 * Filter Hook: the_title
 *
 * @uses		wordsmith_get_default_title()
 *
 * @param		string	$title	The post title
 * @param		int		$id		Post ID
 * @return		string
 */
function wordsmith_untitled_entry( $title, $id ) {

	if ( ! $title ) {
		$title = wordsmith_get_default_title();
	}
	return $title;
}
add_filter( 'the_title', 'wordsmith_untitled_entry', 10, 2 );




/**
 * Modify the 'Read More' link when using the_content()
 *
 * Filter Hook: the_content_more_link
 *
 * @uses		wordsmith_get_more_link()
 *
 * @param		$more_link
 * @param		$more_link_text
 * @return		string
 */
function wordsmith_the_content_more_link( $more_link, $more_link_text ) {
	return wordsmith_get_more_link();
}
add_filter( 'the_content_more_link', 'wordsmith_the_content_more_link', 10, 2 );




/**
 * Add a 'Read More' link at the end of excerpts
 *
 * Filter Hook: excerpt_more
 *
 * @uses		wordsmith_get_more_link()
 * @uses		is_home()
 *
 * @param		string	$more_text		the default string '[...]' appended at the end of excerpts
 * @return		string  the default text plus a 'Read More' link wrapped in a <p> tag
 */
function wordsmith_the_excerpt_more_link( $more_text ) {

	if ( is_home() ) {
		$more_text .= '<p>' . wordsmith_get_more_link() . '</p>';
	}
	return $more_text;
}
add_filter('excerpt_more', 'wordsmith_the_excerpt_more_link');




/**
 * Add a 'Ream More' link to multi-page posts
 *
 * Filter Hook: the_content
 * Filter Hook: the_excerpt
 *
 * @param		string	$content	Original contents of either the_content or the_excerpt
 * @return		string	'Read More' link wrapped in a <p> tag
 */
function wordsmith_multipage_more_link( $content ) {

	global $multipage, $wp_current_filter;

	// Don't do anything if the_content is being used to extract the_excerpt
	if ( in_array( 'get_the_excerpt', $wp_current_filter ) ) {
		return $content;
	}

	if ( $multipage && is_home() ) {

		$more_link = wordsmith_get_more_link();

		// Check if it already has a 'Read More' link
		if ( false === strpos( $content, $more_link ) ) {
			$content .= '<p>' . $more_link . '</p>';
		}
	}

	return $content;
}
add_filter( 'the_content', 'wordsmith_multipage_more_link' );
add_filter( 'the_excerpt', 'wordsmith_multipage_more_link' );




/**
 * Override the default gallery template
 *
 * Filter Hook: post_gallery
 *
 * @param		string	$output	Empty string
 * @param		array	$attr	Attributes attributed to the shortcode.
 * @return		string	HTML content to display the gallery
 */
function wordsmith_gallery_shortcode( $output, $attr ) {

	$post = get_post();

	// We're trusting author input, so let's at least make sure it looks like a valid orderby statement
	if ( isset( $attr['orderby'] ) ) {
		$attr['orderby'] = sanitize_sql_orderby( $attr['orderby'] );
		if ( !$attr['orderby'] )
			unset( $attr['orderby'] );
	}

	extract(shortcode_atts(array(
		'order'      => 'ASC',
		'orderby'    => 'menu_order ID',
		'id'         => $post->ID,
		'itemtag'    => 'figure',
		'icontag'    => 'a',
		'captiontag' => 'figcaption',
		'columns'    => 3,
		'size'       => 'thumbnail',
		'include'    => '',
		'exclude'    => ''
	), $attr));

	$id = intval($id);
	if ( 'RAND' == $order )
		$orderby = 'none';

	if ( !empty($include) ) {
		$_attachments = get_posts( array('include' => $include, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );

		$attachments = array();
		foreach ( $_attachments as $key => $val ) {
			$attachments[$val->ID] = $_attachments[$key];
		}
	} elseif ( !empty($exclude) ) {
		$attachments = get_children( array('post_parent' => $id, 'exclude' => $exclude, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	} else {
		$attachments = get_children( array('post_parent' => $id, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	}

	if ( empty($attachments) )
		return '';

	if ( is_feed() ) {
		$output = "\n";
		foreach ( $attachments as $att_id => $attachment )
			$output .= wp_get_attachment_link($att_id, $size, true) . "\n";
		return $output;
	}

	$output = '<section class="gallery clearfix"><div class="gallery-thumbs">';

	foreach ( $attachments as $id => $attachment ) {

		if ( isset($attr['link']) && 'file' == $attr['link'] ) {
			// link to the image file
			$url = wp_get_attachment_url( $attachment->ID );
		}
		else {
			// link to the attachment page
			$url = get_attachment_link( $attachment->ID );
		}

		$icon = sprintf( '<a href="%1$s" class="gallery-icon">%2$s</a>',
			$url,
			// get attachment thumb
			wp_get_attachment_image( $attachment->ID, 'thumbnail' )
		);

		// get caption, if there is any
		$caption = '';
		if ( trim($attachment->post_excerpt) ) {
			$caption = '<figcaption class="gallery-caption">' . wptexturize( $attachment->post_excerpt ) . '</figcaption>';
		}

		$gallery_item = '<figure class="gallery-item">';
		$gallery_item .= $icon;
		$gallery_item .= $caption;
		$gallery_item .= '</figure>';
		$output .= $gallery_item;
	}

	$output .= '</div></section>';

	return $output;
}
add_filter( 'post_gallery', 'wordsmith_gallery_shortcode', 10, 2 );




/**
 * Override the default caption template.
 *
 * Filter Hook: img_caption_shortcode
 *
 * Based on code by Justin Tadlock
 * @link	http://justintadlock.com/archives/2011/07/01/captions-in-wordpress
 *
 * @uses		shortcode_atts()
 * @uses		do_shortcode()
 * @uses		esc_attr()
 *
 * @param		string	$val		Empty string
 * @param		array	$attr		Attributes attributed to the shortcode
 * @param		string	$content	Shortcode content
 * @return		string  HTML to display the caption
 */
function wordsmith_img_caption_shortcode( $val, $attr, $content = null ) {

	$default_attr = array(
		'id'    => '',
		'align' => 'alignnone',
		'width' => '',
		'caption' => ''
	);
	// Merge the defaults with user input
	$attributes = shortcode_atts( $default_attr, $attr );

	extract( $attributes );

	// If the width is less than 1 or there is no caption,
	// return the original content that goes inside the [caption] tags
	if ( 1 > (int) $width || empty( $caption ) ) {
		return $content;
	}

	if ( $id ) {
		$id = sprintf( 'id="%s"', esc_attr( $id ) );
	}

	$width = sprintf( 'style="width: %spx"', ( 2 + (int) $width ) );

	$output = sprintf(
		'<figure %1$s class="wp-caption %2$s" %3$s >%4$s<figcaption class="wp-caption-text">%5$s</figcaption></figure>',
		$id,
		esc_attr( $align ),
		$width,
		do_shortcode( $content ),
		$caption
	);

	return $output;
}
add_filter( 'img_caption_shortcode', 'wordsmith_img_caption_shortcode', 10, 3 );




/**
 * Find the nearest image size if the specified size is not found
 *
 * Filter Hook: image_downsize
 *
 * @uses		image_get_intermediate_size()
 * @uses		wp_get_attachment_url()
 * @uses		wp_basename()
 * @uses		image_constrain_size_for_editor()
 *
 * @param		bool	$val	False
 * @param		int		$id		Attachment ID for image
 * @param		string	$size	Size of the image
 * @return		bool|array		False if nothing is found or Array with image url, width, height, and whether is intermediate size
 */
function wordsmith_downsize_img( $val, $id, $size ) {

	global $_wp_additional_image_sizes;

	$img_url = wp_get_attachment_url($id);
	$width = $height = 0;
	$is_intermediate = false;
	$img_url_basename = wp_basename($img_url);

	// If $size is an array, image_get_intermediate_size() returns the nearest image size larger
	// If $size is a string, image_get_intermediate_size() tries to find $size in the metadata 'sizes' array
	if ( $intermediate = image_get_intermediate_size($id, $size) ) {
		$img_url = str_replace( $img_url_basename, $intermediate['file'], $img_url );
		$width = $intermediate['width'];
		$height = $intermediate['height'];
		$is_intermediate = true;
	}
	// If $size is a string and image_get_intermediate_size() didn't find $size in the metadata 'sizes' array,
	// let's pass an array to get the nearest image size
	elseif ( ! empty( $_wp_additional_image_sizes[ $size ] ) ) {
		$size_array = $_wp_additional_image_sizes[ $size ];
		$size_array = array( $size_array['width'], $size_array['height'], $size_array['crop'] );

		$intermediate = image_get_intermediate_size($id, $size_array);
		$img_url = str_replace( $img_url_basename, $intermediate['file'], $img_url );
		$width = $intermediate['width'];
		$height = $intermediate['height'];
		$is_intermediate = true;
	}
	// If $size is not found in $_wp_additional_image_sizes either,
	// let image_downsize() take care of the rest
	else {
		return false;
	}

	// we have the actual image size, but might need to further constrain it if content_width is narrower
	list( $width, $height ) = image_constrain_size_for_editor( $width, $height, $size );

	return array( $img_url, $width, $height, $is_intermediate );
}
add_filter( 'image_downsize', 'wordsmith_downsize_img', 10, 3 );




/*	==========================================================================
	Theme Hooks
	========================================================================== */


/**
 * Override the output of wp_link_pages()
 *
 * Filter Hook: wordsmith_link_pages
 *
 * @uses		_wp_link_page()
 *
 * @param		$output		Empty string
 * @return		string		A string containing the formatted output in HTML
 */
function wordsmith_get_link_pages( $output ) {

	global $page, $numpages, $multipage;

	if ( ! $multipage ) {
		return '';
	}

	$output = '';
	$separator = '<span class="entry-pages-separator">&rsaquo;</span>';
	$pages = array();

	for ( $i = 1; $i < ($numpages+1); $i = $i + 1 ) {
		$link_text = sprintf( __( 'Page %s', 'wordsmith' ), $i );

		// Current page
		if ( $i == $page ) {
			$page_link = '<span class="page-numbers current">' . $link_text . '</span>';
		}
		// Link to another page
		else {
			$open_link_tag = substr_replace( _wp_link_page($i), 'class="page-numbers">', -1 );
			$page_link =  $open_link_tag . $link_text . '</a>';
		}

		$pages[] = $page_link;
	}

	if ( ! empty( $pages ) ) {
		$output = '<p class="entry-pages">' . implode( $separator, $pages ) . '</p>';
	}

	return $output;
}
add_filter( 'wordsmith_link_pages', 'wordsmith_get_link_pages' );