<?php
/**
 * Custom Template Tags
 *
 * This file defines functions used as custom template tags.
 *
 * @package			Wordsmith
 * @copyright		Copyright (C) 2013 Victor Sarabia
 * @license			http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License v2
 * @since			Wordsmith 0.1
 */




/**
 * Prints the site name and description in the nameplate
 *
 * @uses		home_url()
 * @uses		get_bloginfo()
 * @uses		is_front_page()
 */
function wordsmith_the_site_info() {

	$site_title = sprintf( '<a href="%1$s" class="site-title">%2$s</a>',
		esc_url( home_url( '/' ) ),
		get_bloginfo( 'name' )
	);

	$site_description = '<span class="site-description">' . get_bloginfo( 'description' ) .  '</span>';

	// Use an <h1> only for the front page and an <h4> anywhere else
	if ( is_front_page() ) {
		echo '<h1 class="site-info">' . $site_title. ' ' . $site_description . '</h1>';
	}
	else {
		echo '<h4 class="site-info">' . $site_title . ' ' . $site_description . '</h4>';
	}
}




/**
 * Prints the entry's date in localized format
 *
 * Uses the Date Format set by the user in: Settings->General Settings
 *
 * @uses		get_the_time()
 * @uses		date_i18n()
 * @uses		get_option()
 */
function wordsmith_the_date() {

	$datetime = get_the_time('Y-m-d');
	$unixtimestamp = strtotime( get_the_time('n/j/Y') );
	$date = date_i18n( get_option('date_format'), $unixtimestamp );

	printf( '<time datetime="%1$s" class="entry-date"><span>%2$s</span></time>',
		esc_attr( $datetime ),
		$date
	);
}




/**
 * Prints the title of the current entry
 *
 * @uses		get_the_title()
 * @uses		get_permalink()
 * @uses		is_singular()
 */
function wordsmith_the_title() {

	global $post;

	$classname = ( 'page' == $post->post_type ) ? 'page-title' : 'entry-title';
	$title = get_the_title();

	// <h1> title without link for single pages
	if ( is_singular() ) {
		$title_tag = sprintf(
			'<h1 class="%1$s">%2$s</h1>',
			$classname,
			$title
		);
	}
	// <h2> title with permalink anywhere else
	else {
		$title_tag = sprintf(
			'<h2 class="%1$s"><a href="%2$s" title="%3$s">%4$s</a></h2>',
			$classname,
			get_permalink(),
			__( 'Read the full post', 'wordsmith' ),
			$title
		);
	}

	echo $title_tag;
}




/**
 * Prints the entry's author
 *
 * @uses		get_the_author()
 */
function wordsmith_the_author() {

	/* translators: Used to indicate the person responsible for writing the post. As in "written by" */
	echo '<span class="entry-author">' . __( 'by', 'wordsmith' ) . ' ' . get_the_author() . '</span>';
}




/**
 * Displays the post thumbnail
 *
 * @uses		wordsmith_get_options()
 * @uses		has_post_thumbnail()
 * @uses		is_singular()
 * @uses		the_post_thumbnail()
 * @uses		get_the_post_thumbnail()
 * @uses		get_permalink()
 * @uses		get_the_title()
 */
function wordsmith_the_post_thumbnail() {

	global $post;

	if ( ! has_post_thumbnail() ) {
		return;
	}

	$size = wordsmith_get_options( 'post_thumbnail_size' );
	$class = is_singular() ? '' : 'alignleft';
	$attr = array(
		'title'	=> '',
		'class'	=> $class
	);

	// Post-Thumbnail without link
	if ( is_singular() ) {
		the_post_thumbnail( $size, $attr );
	}
	// Post-Thumbnail with permalink
	else {
		printf( '<a href="%1$s" title="%2$s">%3$s</a>',
			get_permalink( $post ),
			__( 'Continue reading &raquo; ', 'wordsmith' ) . get_the_title( $post ),
			get_the_post_thumbnail( $post->ID, $size, $attr )
		);
	}
}




/**
 * Print the category links section for the post.
 *
 * @uses		the_category()
 */
function wordsmith_the_category() {
?>
	<section class="entry-categories">
		<h4 class="section-title"><?php _e( 'Posted in:', 'wordsmith' ); ?></h4>
		<p class="cat-links">
			<?php the_category( ' &nbsp;&#x2044;&nbsp; ' ); ?>
		</p>
	</section>
<?php
}




/**
 * Print links for each tag assigned to the post.
 *
 * If no tags are associated with the current entry, nothing is displayed
 *
 * @uses		has_tag()
 * @uses		the_tags()
 */
function wordsmith_the_tags() {

if ( has_tag() ) : ?>
	<section>
		<h4 class="section-title"><?php _e( 'Tags:', 'wordsmith' ); ?></h4>
		<p class="tag-links">
			<?php the_tags( '', ' / ' ); ?>
		</p>
	</section>
<?php endif;
}




/**
 * Return page links for paginated posts and pages
 *
 * The entry needs to have the <!--nextpage--> quicktag one or more times to be split into pages
 *
 * By default, this function will return the result of wp_link_pages()
 * However, the function also provides a custom filter 'wordsmith_link_pages'
 * which can be used to override the default output of wp_link_pages()
 *
 * @uses		apply_filters()
 * @uses		wp_link_pages()
 *
 * @return		string|void		A string containing the formatted output in HTML
 */
function wordsmith_get_entry_pages() {

	// Allow others to override the default output
	$page_links = apply_filters( 'wordsmith_link_pages' , '' );
	if ( $page_links ) {
		return $page_links;
	}

	// Fallback to wp_link_pages()
	return wp_link_pages( array( 'echo' => 0 ) );
}




/**
 * Display the entry content
 *
 * @uses		wordsmith_get_options()
 * @uses		wordsmith_get_entry_pages()
 * @uses		the_content()
 * @uses		the_excerpt()
 * @uses		is_singular()
 */
function wordsmith_the_content() {

	$is_singular = is_singular();

	// Show page links only in single post/page views
	$page_links = $is_singular ? wordsmith_get_entry_pages() : '';

	if ( $is_singular || wordsmith_get_options( 'display_full_posts' ) ) {
		echo $page_links;
		the_content();
		echo $page_links;
	}
	else {
		the_excerpt();
	}
}




/**
 * Get the read more link
 *
 * @uses		get_the_title()
 * @uses		get_permalink()
 *
 * @return		string	A string containing a link tag to the full post
 */
function wordsmith_get_more_link() {

	global $post;

	$link_text = __( 'Continue reading', 'wordsmith' ) . ' &raquo; <span class="more-link-title">' . get_the_title( $post ) . ' </span>';

	return sprintf( '<a href="%1$s" class="more-link">%2$s</a>',
		get_permalink( $post ),
		$link_text
	);
}




/**
 *	Prints pagination links
 *
 *	A wrapper function for paginate_links()
 *	Echoes a list of page links for navigation
 *	Example: ( «Previous 1 … 3 4 5 6 7 … 9 Next» )
 *	Can be used to add pagination to the main posts page, archives and the search results page
 *
 *	@uses		paginate_links()
 *	@uses		get_query_var()
 *	@uses		get_pagenum_link()
 *  @uses		is_singular()
 */
function wordsmith_paginate_links() {

	if ( is_singular() ) {
		return;
	}

	global $wp_query;

	$placeholder = 999999999; // this will be replaced by '%#%'
	$base = str_replace( $placeholder, '%#%', get_pagenum_link( $placeholder ) );
	$current = max( 1, get_query_var( 'paged' ) );

	$page_links = paginate_links(
		array(
			'base'			=> $base,
			'current'		=> $current,
			'total'			=> $wp_query->max_num_pages,
			'prev_text'		=> __( '&laquo; Previous', 'wordsmith' ),
			'next_text'		=> __( 'Next &raquo;', 'wordsmith' ),
			'type'			=> 'array'
		)
	);

	if ( empty( $page_links ) ) {
		return;
	}

	// Add title attribute to Prev and Next
	$prev_title = sprintf( 'title="%s" ', __( 'Previous page - Newer posts', 'wordsmith' ) );
	$next_title = sprintf( 'title="%s" ', __( 'Next page &#8403; Older posts', 'wordsmith' ) );
	$last_item = count( $page_links ) - 1;

	$page_links[ 0 ] = str_replace( 'class="prev', ( $prev_title . 'class="prev' ), $page_links[ 0 ] );
	$page_links[ $last_item ] = str_replace( 'class="next', ( $next_title . 'class="next' ), $page_links[ $last_item ] );

	$page_links = implode( '', $page_links );

	echo '<p class="posts-pagination">';
	echo $page_links;
	echo '</p>';
}




/**
 * Displays the total number of search results found
 */
function wordsmith_search_results_total() {

	global $wp_query;
	$total_results = $wp_query->found_posts;
	$search_term = get_search_query();

	if ( 0 == $total_results ) {
		$output = __('No results found for:', 'wordsmith') . ' <em>' . $search_term . '</em>';
	} else {
		/* translators: %s stands for the number of search results found. */
		$output = _n( '1 result found for:', '%s results found for:', $total_results, 'wordsmith' );
		$output = sprintf( $output, $total_results ) . ' <em>' . $search_term . '</em>';
	}

	echo $output;
}