<?php
/**
 * Wordsmith Theme Setup
 *
 * This file defines setup functions for the Wordsmith Theme.
 *
 * @package			Wordsmith
 * @copyright		Copyright (C) 2013 Victor Sarabia
 * @license			http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License v2
 * @since			Wordsmith 0.1
 */




/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 664; // pixels
}




/**
 * Wordsmith Theme Options Defaults
 *
 * Returns array with all
 * the default values for the theme options.
 *
 * @return		array	$defaults	associative array of default theme settings
 */
function wordsmith_get_options_defaults() {

	return array(
		// Whether to display full posts or excerpts - the default is to display excerpts
		'display_full_posts'	=> 0,
		// Post thumbnail size
		'post_thumbnail_size'	=> 'wordsmith-thumbnail',
	);
}




/**
 * Get Wordsmith Theme Options
 *
 * Returns array with all the settings defined for the theme.
 * If a value is not found in the database,
 * then the default value is used instead.
 *
 * The function accepts an optional parameter $option_name
 * to retrieve the value of a single option.
 * Otherwise it returns an array with all the options.
 *
 * @uses		wordsmith_get_options_defaults()
 * @uses		get_option()
 * @uses		wp_parse_args()
 *
 * @param		string	$option_name	(optional) name of the option to retrieve
 * @return		mixed	array with the current values for all the theme options OR the value of a single option
 */
function wordsmith_get_options( $option_name = '' ) {

	static $theme_settings;

	if ( ! isset( $theme_settings ) ) {
		// Merge settings stored in the database with defaults
		$theme_settings = wp_parse_args(
			get_option( 'wordsmith_theme_settings', array() ),
			wordsmith_get_options_defaults()
		);
	}

	if ( 'display_full_posts' == $option_name ) {
		return $theme_settings[ 'display_full_posts' ];
	}
	elseif ( 'post_thumbnail_size' == $option_name ) {
		return $theme_settings[ 'post_thumbnail_size' ];
	}

	return $theme_settings;
}




/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * Action Hook: after_setup_theme
 *
 * @uses		load_theme_textdomain() For translation/localization support.
 * @uses		register_nav_menus() To add support for navigation menus.
 * @uses		add_theme_support() To add support for post thumbnails, automatic feed links
 * @uses		add_image_size()
 * @uses		set_post_thumbnail_size() To set a custom post thumbnail size.
 * @uses		add_editor_style() To style the visual editor.
 */
function wordsmith_setup() {

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'main-nav'	=> __( "The theme's main menu", 'wordsmith' )
		)
	);

	// Register additional image sizes
	add_image_size( 'wordsmith-thumbnail', 150, 150, true );

	// Enable support for Post Thumbnails
	add_theme_support( 'post-thumbnails' );

	// Set the default Post Thumbnail size
	set_post_thumbnail_size( 150, 150, true );

	// Automatically add RSS feed links to document <head>
	add_theme_support( 'automatic-feed-links' );
}
/**
 *	Tell WordPress to run wordsmith_setup() when the 'after_setup_theme' hook is run.
 */
add_action( 'after_setup_theme', 'wordsmith_setup' );




/**
 * Register sidebars and widgetized areas.
 *
 * Action Hook: widgets_init
 *
 * @uses		register_sidebar()
 */
function wordsmith_widgets_init() {

	register_sidebar(
		array(
			'name'			=> __( 'Main Sidebar', 'wordsmith' ),
			'id'			=> 'main-sidebar',
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s">',
			'after_widget'	=> "</aside>",
			'before_title'	=> '<h4 class="widget-title">',
			'after_title'	=> '</h4>'
		)
	);

	register_sidebar(
		array(
			'name'			=> __( 'Footer Sidebar', 'wordsmith' ),
			'id'			=> 'footer-sidebar',
			'description'	=> __( 'An optional widget area for your site footer', 'wordsmith' ),
			'before_widget'	=> '<aside id="%1$s" class="widget footer-widget %2$s">',
			'after_widget'	=> "</aside>",
			'before_title'	=> '<h4 class="widget-title footer-widget-title">',
			'after_title'	=> '</h4>'
		)
	);
}
add_action( 'widgets_init', 'wordsmith_widgets_init' );




/**
 * Get the default title to use when a post has no title
 *
 * @return		string
 */
function wordsmith_get_default_title() {
	return __( 'Untitled', 'wordsmith' );
}